woe\_linear\_bin
================

The core code is include split\_data and apply\_woetab. the function
split\_data then split\_onevar is split then split the continuous
variable, the ouput woe value is monotonous and the applywoetab is
translet the origin data into woetab
